@@ -36,8 +36,8 @@ void F77_SUB(epllk)(double *beta,double *etaSg0,double *etaSg,
                     double *etaPvS,double *etaCrF, double *etaCrS, 
                     double *wk1, int *ipvt, double *A2ina1,
                     double *A2inc1, double *A2mat, double *A2str,
-                    double *R2comp, double *wk2,double *R5, double *R5TA2, 
-                    double *vR5TA2, double *xkpan1, double *xkpan2, 
+                    double *R2comp, double *wk2, double *R5, double *R5TA2, 
+                    double *vR5TA2, double *xkans1, double *xkans2, 
                     double *B2inb1, double *work, double *A2neg, 
                     double *B2mat, double *B2neg, double *xm2A2, 
                     double *det, double *wka, double *wkb, double *wkv, 
